# Contributing to the Cell Browser

Thanks for taking the time to contribute!

You've found a bug or have an idea for a feature? 
Great! You can open an issue in Github. If you don't know what that means, just email us
at cells@ucsc.edu. We are happy about any pull requests. We try to get back to you within 1-2 days, especially on obvious bugs.
Before you submit a pull request, don't hesitate to ask by email or via an issue. Maybe we are already working on it or have some opinion how to best implement something.

## Contribution Guidelines

* Make sure your text editor is set to remove tab characters and replaces them with spaces.
* We use K&R indentation, camelCase variable names and globals are not uppercase, but don't worry, we can fix up any PRs for you
* The main Javascript file is src/cbPyLib/cellbrowser/cbWeb/js/cellbrowser.js
* The main Python code is src/cbPyLib/cellbrowser/cellbrowser.py
